local params = ...

local _network = require("network")
local _logger = require("logging")
local _core = require("core")
local _timer = require("timer")

local ENABLE_UDP_SERVER_SETTING_NAME = "enable_udp_server"
local THIS_SCRIPT = "HUB:ezlo_protocols/scripts/events/events_handler"
local TIMER_ID = THIS_SCRIPT
local UDP_TIMEOUT = 1000 -- milliseconds
local DATA_LIMIT = 1000

local udp_item_id = _G.ezlo_protocols["udp_server_receive"]

if params.event then

    local data = _G.ezlo_protocols[tostring(params.data.event.handle)]
    _G.ezlo_protocols[tostring(params.data.event.handle)] = nil

    if params.data.event.io_activity_type == "FAILED_TO_CONNECT" then
        _logger.info("Failed to connect to the server")
        _network.close(params.data.event.handle)

        return
    end

    if params.data.event.io_activity_type == "CLOSED" then
        _network.close(params.data.event.handle)

        return
    end

    if params.data.event.io_activity_type == "CONNECTED" then
        if data == "udp" then
            return
        end
        if _G.ezlo_protocols[ENABLE_UDP_SERVER_SETTING_NAME] == params.data.event.handle then
            _logger.info("The server is enabled")
            return
        end

        while true do
            local success, errmsg = pcall(_network.send, params.data.event.handle, data.data)

            if not success then
                _logger.error("Failed to send data, error: " .. errmsg)
            else
                local count_of_send_data = errmsg

                if count_of_send_data == string.len(data.data) then
                    break
                else
                    data.data = string.sub(data.data, count_of_send_data + 1)
                end
            end
        end

        _logger.info("The data is sent")
        _network.close(params.data.event.handle)
    end

    if params.data.event.io_activity_type == "IN" then

        if not _timer.exists(TIMER_ID) then
            _timer.set_timeout_with_id(UDP_TIMEOUT, TIMER_ID, THIS_SCRIPT, {})
        end

        if not _G.ezlo_protocols.udp_data then
            _G.ezlo_protocols.udp_data = _network.receive(params.data.event.handle) or {}
        else
            _G.ezlo_protocols.udp_data = _G.ezlo_protocols.udp_data .. _network.receive(params.data.event.handle)
        end

        if #_G.ezlo_protocols.udp_data > DATA_LIMIT then
            _G.ezlo_protocols.udp_data = string.sub(_G.ezlo_protocols.udp_data, 1, DATA_LIMIT)
            _core.update_item_value(udp_item_id, {
                data = _G.ezlo_protocols.udp_data
            })
            _timer.cancel(TIMER_ID)
            _G.ezlo_protocols.udp_data = nil
        end

        return
    end

elseif params.timerId then

    if _G.ezlo_protocols.udp_data then
        _core.update_item_value(udp_item_id, {
            data = _G.ezlo_protocols.udp_data
        })
        _G.ezlo_protocols.udp_data = nil
    end

    return
end
