local _core = require("core")
local _logger = require("logging")

local params = ...

local items = {}

if type(params.item_id) == "string" then
    items[params.item_id] = { value = params.value }

elseif type(params.item_ids) == "table" then
    for _, item_id in ipairs(params.item_ids) do
        items[item_id] = { value = params.value }
    end

elseif type(params.items) == "table" then
    items = params.items
end

for item_id, item_params in pairs(items) do
    local item = _core.get_item(item_id)

    local item_handler = item.name

    local item_script = loadfile("HUB:ezlo_protocols/scripts/items/" .. item_handler)
    
    if not item_script then
        _logger.error("Failed to load handler for item: " .. item.name)
    end

    local success, errmsg = pcall(item_script, {
        device_id = item.device_id,
        item_id = item_id,
        value = item_params.value,
        action = "set"
    })

    if not success then
        _logger.error("Failed to set item: " .. item.name .. ", error: " .. errmsg)
    end
end
