local _logger = require("logging")

local SETTING_NAME = "enable_udp_server"

local function CreateOrUpdateSetting(device_id, setting_id, value)
    value = value or false

    if setting_id then
        local _core = require("core")
        _logger.debug("Update setting value: " .. SETTING_NAME .. " = " .. tostring(value))
        _core.set_setting_value(setting_id, value, "synced")

        pcall(loadfile("HUB:ezlo_protocols/scripts/items/udp_server_receive"), {
            device_id = device_id,
            action = value and "enable" or "disable"
        })
        
        return
    end

    local _setting_utils = require("HUB:ezlo_protocols/scripts/modules/setting_utils")

    local setting = {
        label = {
            text = "Enable UDP Server"
        },
        description = {
            text = "Only open a UDP socket if this option is ON.."
        },
        value_type = "bool",
        value = value,
        status = "synced",
        has_setter = true,
        info = {
            name = SETTING_NAME
        }
    }

    _setting_utils.CreateSetting(device_id, SETTING_NAME, setting)
end

local params = ... or {}

if not params.device_id then
    _logger.error("Missing device_id. Cannot continue.")

    return
end

CreateOrUpdateSetting(params.device_id, params.setting_id, params.value)
