local _logger = require("logging")

local SETTING_NAME = "http_id"
local ENABLE_HTTP_SERVER_SETTING_NAME = "enable_http_server"

local function CreateOrUpdateSetting(device_id, setting_id, value)
    if not value then
        value = ""
    end

    if setting_id then
        local _core = require("core")

        local setting = _core.get_setting(setting_id)

        if setting.value == value then
            _logger.warning("This ID is already set up.")

            return
        end

        local current_value = setting.value
        _G.ezlo_protocols["HTTP_ID_CURRENT_VALUE"] = current_value

        _logger.debug("Update setting value: " .. SETTING_NAME .. " = " .. tostring(value))
        _core.set_setting_value(setting_id, value, "synced")

        if _G.ezlo_protocols[ENABLE_HTTP_SERVER_SETTING_NAME] then
            loadfile("HUB:ezlo_protocols/scripts/items/http_server_receive") {
                device_id = device_id,
                action = "restart"
            }
        end
        
        return
    end

    local _setting_utils = require("HUB:ezlo_protocols/scripts/modules/setting_utils")

    local setting = {
        label = {
            text = "HTTP ID"
        },
        description = {
            text = "The ID that gets appended at the end of the url path."
        },
        value_type = "string",
        value = value,
        status = "synced",
        has_setter = true,
        info = {
            name = SETTING_NAME
        }
    }

    _setting_utils.CreateSetting(device_id, SETTING_NAME, setting)

end

local params = ... or {}

if not params.device_id then
    _logger.error("Missing device_id. Cannot continue.")

    return
end

CreateOrUpdateSetting(params.device_id, params.setting_id, params.value)
