local _logger = require("logging")

local SETTING_NAME = "udp_server_port"
local ENABLE_UDP_SERVER_SETTING_NAME = "enable_udp_server"

local function CreateOrUpdateSetting(device_id, setting_id, value)
    value = value or 2222

    if setting_id then
        local _core = require("core")
        _logger.debug("Update setting value: " .. SETTING_NAME .. " = " .. tostring(value))
        local setting = _core.get_setting(setting_id)

        if setting.value == value then
            _logger.warning("This port is already set up.")
            
            return
        end

        _core.set_setting_value(setting_id, value, "synced")

        if _G.ezlo_protocols[ENABLE_UDP_SERVER_SETTING_NAME] then
            loadfile("HUB:ezlo_protocols/scripts/items/udp_server_receive") {
                device_id = device_id,
                action = "restart"
            }
        end

        return
    end

    local _setting_utils = require("HUB:ezlo_protocols/scripts/modules/setting_utils")
    

    local setting = {
        label = {
            text = "UDP Server Port"
        },
        description = {
            text = "The port to use for incoming UDP connections."
        },
        value_type = "int",
        value = value,
        status = "synced",
        has_setter = true,
        info = {
            name = SETTING_NAME        }
    }

    _setting_utils.CreateSetting(device_id, SETTING_NAME, setting)
end

local params = ... or {}

if not params.device_id then
    _logger.error("Missing device_id. Cannot continue.")

    return
end

CreateOrUpdateSetting(params.device_id, params.setting_id, params.value)
