local _logger = require("logging")
local ENABLE_HTTP_SERVER_SETTING_NAME = "enable_http_server"
local HTTP_ID_SETTING_NAME = "http_id"
local SETTING_NAME = "use_https"
local HTTP_SERVER_URL_SETTING_NAME = "http_server_url"

local function CreateOrUpdateSetting(device_id, setting_id, value)
    local _http_server = require("http_server")

    if value == nil then
        value = true
    end

    if setting_id then
        local _core = require("core")
        
        _logger.debug("Update setting value: " .. SETTING_NAME .. " = " .. tostring(value))
        _core.set_setting_value(setting_id, value, "synced")
        
        if _G.ezlo_protocols[ENABLE_HTTP_SERVER_SETTING_NAME] then
            
            local http_id_setting = loadfile("HUB:ezlo_protocols/scripts/functions/get_setting_by_name") {
                device_id = device_id,
                setting_name = HTTP_ID_SETTING_NAME
            }

            local success, url_info = pcall(_http_server.get_link_info, http_id_setting.value)

            if not success then
                _logger.error("The link does not exist. Cannot continue.")
            end

            local http_server_url_setting = loadfile("HUB:ezlo_protocols/scripts/functions/get_setting_by_name") {
                device_id = device_id,
                setting_name = HTTP_SERVER_URL_SETTING_NAME
            }

            local url = url_info.url

            if value == true then
                url = url_info.secure_url
            end


            _core.set_setting_value(http_server_url_setting.id, url, "synced")
        end

        return
    end

    local _setting_utils = require("HUB:ezlo_protocols/scripts/modules/setting_utils")

    local setting = {
        label = {
            text = "Use HTTPS"
        },
        description = {
            text = "Use https server instead of http."
        },
        value_type = "bool",
        value = value,
        status = "synced",
        has_setter = true,
        info = {
            name = SETTING_NAME
        }
    }
    
    _setting_utils.CreateSetting(device_id, SETTING_NAME, setting)

end

local params = ... or {}

if not params.device_id then
    _logger.error("Missing device_id. Cannot continue.")

    return
end

CreateOrUpdateSetting(params.device_id, params.setting_id, params.value)
